@@ -4,6 +4,4 @@ from .aml import Aml
 from .transformers import ColSelector, TypeCaster, \
     OrdinalEncoder, NanImputer, NullishToNan, OutlierTrimmer, \
     OnehotEncoder, StdScaler, MinMaxScaler, BoxCoxTransformer, \
-    PipeMerger 
-from .plot import ts_outlier_plot, separability_plot, \
-    correl_plot, univariate_plot, qq_plot
\ No newline at end of file
+    PipeMerger 
\ No newline at end of file
